package com.zbf.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper; //添加
import com.zbf.system.domain.TBaseGoodsBom;

/**
 * 物料bomMapper接口
 *
 * @author tony
 * @date 2024-06-16
 */
public interface TBaseGoodsBomMapper extends BaseMapper<TBaseGoodsBom> //修改
{
    /**
     * 查询物料bom
     *
     * @param id 物料bom主键
     * @return 物料bom
     */
    public TBaseGoodsBom selectTBaseGoodsBomById(Long id);

    /**
     * 查询物料bom列表
     *
     * @param tBaseGoodsBom 物料bom
     * @return 物料bom集合
     */
    public List<TBaseGoodsBom> selectTBaseGoodsBomList(TBaseGoodsBom tBaseGoodsBom);

    /**
     * 新增物料bom
     *
     * @param tBaseGoodsBom 物料bom
     * @return 结果
     */
    public int insertTBaseGoodsBom(TBaseGoodsBom tBaseGoodsBom);

    /**
     * 修改物料bom
     *
     * @param tBaseGoodsBom 物料bom
     * @return 结果
     */
    public int updateTBaseGoodsBom(TBaseGoodsBom tBaseGoodsBom);

    /**
     * 删除物料bom
     *
     * @param id 物料bom主键
     * @return 结果
     */
    public int deleteTBaseGoodsBomById(Long id);

    /**
     * 批量删除物料bom
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTBaseGoodsBomByIds(Long[] ids);

    /**
     * 批量启用物料bom
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTBaseGoodsBomByIds(Long[] ids);

    /**
     * 批量禁用物料bom
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTBaseGoodsBomByIds(Long[] ids);

}
